function [xx,yy]=ee(f,x0,xn,y0,h)
% function [xx,yy]=ee(f,x0,xn,y0,h)
% explicitni Eulerova metoda pro rovnici y'=f(x,y)
% f  - anonymni funkce promennych x,y
% x0 - zacatek intervalu
% xn - konec intervalu
% y0 - pocatecni hodnota
% h  - krok

x=x0;
y=y0;
xx=x0;
yy=y0;
while x<xn
    y=y+h*f(x,y);
    x=x+h;
    xx=[xx,x];
    yy=[yy,y];
end
